core library
Classes
- Translation
- A singleton class for managing translations and locale in-app.
- TranslationDelegate
- A delegate interface for managing translations and locale changes.
Constants
- kDefaultTranslationName → const String
- Default translation keys
- kDefaultTranslationPath → const String