TranslationLocale extension

Extension on Locale to provide formatted language codes suitable for translation or localization keys.

on

Properties

formatedLanguageCode String

Available on Locale, provided by the TranslationLocale extension

Returns a formatted language code, optionally including a country code.
no setter