TranslationNumberHelper extension

Extension on num to provide localized number formatting helpers.

on

Properties

trNumber String

Available on num, provided by the TranslationNumberHelper extension

Returns the number formatted according to the current locale.
no setter

Methods

trNumWithOption({bool applyRtl = true}) String

Available on num, provided by the TranslationNumberHelper extension

Returns the number formatted with optional right-to-left formatting.