locale property
String
get
locale
Returns the full locale string combining language and country codes.
Implementation
String get locale => "${code}_$countryCode";
Returns the full locale string combining language and country codes.
String get locale => "${code}_$countryCode";