LocalizableString constructor
Creates a LocalizableString from a map of language codes to strings.
Implementation
const LocalizableString(this._strings);
Creates a LocalizableString from a map of language codes to strings.
const LocalizableString(this._strings);