copyWith method
Returns a copy of this object, optionally replacing the internal map.
Implementation
LocalizableString copyWith({Map<String, String>? strings}) {
return LocalizableString(strings ?? _strings);
}
Returns a copy of this object, optionally replacing the internal map.
LocalizableString copyWith({Map<String, String>? strings}) {
return LocalizableString(strings ?? _strings);
}