isNotEmpty property
bool
get
isNotEmpty
Returns true if at least one localized string is available.
Implementation
bool get isNotEmpty => _strings.isNotEmpty;
Returns true if at least one localized string is available.
bool get isNotEmpty => _strings.isNotEmpty;