verified property
LocalizableString?
get
verified
Returns this instance if it contains at least one string; otherwise null.
Implementation
LocalizableString? get verified => use.isNotEmpty ? this : null;
Returns this instance if it contains at least one string; otherwise null.
LocalizableString? get verified => use.isNotEmpty ? this : null;