TextureIcons class

A collection of commonly used text-based icons.

Provides easy access to Unicode symbols for UI elements like check marks, crosses, and circles.

Constructors

TextureIcons(String icon)
Creates a custom texture icon.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icon String
The actual Unicode symbol for the icon.
final
isNone bool
Returns true if the icon is empty (i.e., none).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

checkMark → const TextureIcons
Check mark symbol ✔
checkMarkBoxGreen → const TextureIcons
Green check mark inside a box ✅
checkMarkBoxGrey → const TextureIcons
Grey check mark inside a box ☑️
checkMarkGrey → const TextureIcons
Grey check mark ✔️
circleBlack → const TextureIcons
Black circle ⚫
circleGreen → const TextureIcons
Green circle 🟢
circleRadio → const TextureIcons
Radio button circle 🔘
circleRed → const TextureIcons
Red circle 🔴
circleWhite → const TextureIcons
White circle ⚪
crossMark → const TextureIcons
Cross mark ✖
crossMarkBlocked → const TextureIcons
Blocked cross mark 🚫
crossMarkGrey → const TextureIcons
Grey cross mark ✖️
crossMarkRed → const TextureIcons
Red cross mark ❌
none → const TextureIcons
No icon / empty icon.