widgets library
Classes
- TranslationButton
- A button widget that allows users to select or change the current locale.
- TranslationProvider
- A provider widget to initialize and manage translations throughout the app.
Mixins
-
TranslationMixin<
S extends StatefulWidget> -
A mixin to simplify locale, translation, and text direction handling in
StatefulWidgets.