TranslationButtonTextExtension extension

Extension on Locale to provide convenient text representation for use in translation buttons or UI elements.

on

Properties

text String

Available on Locale, provided by the TranslationButtonTextExtension extension

Returns the default text representation of the locale.
no setter

Methods

textWithOptions({TranslationButtonType type = TranslationButtonType.flagAndNameInEn, bool markAsDefault = false, TextureIcons selectedIcon = TextureIcons.none}) String

Available on Locale, provided by the TranslationButtonTextExtension extension

Returns a text representation of the Locale with custom options.