utils/language library

Classes

Language
A class representing a language, including its code, optional country code, numerical digits, and names in English and native scripts.

Extensions

LanguageHelper on Locale
Extension helper for Locale to easily get Language objects.

Properties

kLanguages Iterable<Language>
List of all languages initialized from English names.
final